@@ -17,14 +17,15 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 
-DSD_UniformNoise <- function(d=2) 
-    structure(list(description = "Uniform Noise Data Stream", d = d),
+DSD_UniformNoise <- function(d=2, range=NULL) {
+  if(is.null(range)) range <- matrix(c(0,1), ncol=2, nrow=d, byrow=TRUE)
+  structure(list(description = "Uniform Noise Data Stream", d = d, range=range),
 	      class=c("DSD_UniformNoise","DSD_R","DSD"))
-
+  }
+  
 get_points.DSD_UniformNoise <- function(x, n=1, assignment = FALSE, ...) {
-
-    data <- as.data.frame(t(replicate(n, runif(x$d))))
-    
-    if(assignment) attr(data, "assignment") <- rep(NA, n)
+    data <- as.data.frame(t(replicate(n, 
+      runif(x$d, min=x$range[,1], max=x$range[,2]))))
+    if(assignment) attr(data, "assignment") <- rep(NA_integer_, n)
     data
 }
