@@ -4,7 +4,7 @@
 ###################################################
 ### code chunk number 1: stream.Rnw:112-113
 ###################################################
-options(width = 75, digits = 3)
+options(width = 75, digits = 3, prompt='R> ')
 
 
 ###################################################
